@@ -1,4 +1,12 @@
 package YAML::Tiny;
+BEGIN {
+  $YAML::Tiny::AUTHORITY = 'cpan:ADAMK';
+}
+{
+  $YAML::Tiny::VERSION = '1.54';
+}
+# git description: v1.53-15-g5303ddd
+
 
 use strict;
 
@@ -15,8 +23,6 @@ BEGIN {
 	require 5.004;
 	require Exporter;
 	require Carp;
-	$YAML::Tiny::VERSION   = '1.53';
-	# $YAML::Tiny::VERSION   = eval $YAML::Tiny::VERSION;
 	@YAML::Tiny::ISA       = qw{ Exporter  };
 	@YAML::Tiny::EXPORT    = qw{ Load Dump };
 	@YAML::Tiny::EXPORT_OK = qw{ LoadFile DumpFile freeze thaw };
@@ -596,7 +602,7 @@ sub LoadFile {
 	if ( wantarray ) {
 		return @$self;
 	} else {
-		# Return only the last document to match YAML.pm, 
+		# Return only the last document to match YAML.pm,
 		return $self->[-1];
 	}
 }
@@ -653,7 +659,7 @@ easier to read, but with a formal specification that is more complex than
 XML.
 
 The original pure-Perl implementation L<YAML> costs just over 4 megabytes
-of memory to load. Just like with Windows .ini files (3 meg to load) and
+of memory to load. Just like with Windows F<.ini> files (3 meg to load) and
 CSS (3.5 meg to load) the situation is just asking for a B<YAML::Tiny>
 module, an incomplete but correct and usable subset of the functionality,
 in as little code as possible.
@@ -664,13 +670,13 @@ and can be inlined into other modules if needed.
 
 In exchange for this adding this extreme flexibility, it provides support
 for only a limited subset of YAML. But the subset supported contains most
-of the features for the more common usese of YAML.
+of the features for the more common uses of YAML.
 
 =head1 SYNOPSIS
 
     #############################################
     # In your file
-    
+
     ---
     rootproperty: blah
     section:
@@ -678,33 +684,33 @@ of the features for the more common usese of YAML.
       three: four
       Foo: Bar
       empty: ~
-    
-    
-    
+
+
+
     #############################################
     # In your program
-    
+
     use YAML::Tiny;
-    
+
     # Create a YAML file
     my $yaml = YAML::Tiny->new;
-    
+
     # Open the config
     $yaml = YAML::Tiny->read( 'file.yml' );
-    
+
     # Reading properties
     my $root = $yaml->[0]->{rootproperty};
     my $one  = $yaml->[0]->{section}->{one};
     my $Foo  = $yaml->[0]->{section}->{Foo};
-    
+
     # Changing data
     $yaml->[0]->{newsection} = { this => 'that' }; # Add a section
     $yaml->[0]->{section}->{Foo} = 'Not Bar!';     # Change a value
     delete $yaml->[0]->{section};                  # Delete a value
-    
+
     # Add an entire document
     $yaml->[1] = [ 'foo', 'bar', 'baz' ];
-    
+
     # Save the file
     $yaml->write( 'file.conf' );
 
@@ -725,13 +731,17 @@ I said B<human-readable> and not B<geek-readable>. The sort of files that
 your average manager or secretary should be able to look at and make
 sense of.
 
-L<YAML::Tiny> does not generate comments, it won't necesarily preserve the
+=for stopwords normalise
+
+L<YAML::Tiny> does not generate comments, it won't necessarily preserve the
 order of your hashes, and it will normalise if reading in and writing out
 again.
 
 It only supports a very basic subset of the full YAML specification.
 
-Usage is targetted at files like Perl's META.yml, for which a small and
+=for stopwords embeddable
+
+Usage is targeted at files like Perl's META.yml, for which a small and
 easily-embeddable module is extremely attractive.
 
 Features will only be added if they are human readable, and can be written
@@ -740,7 +750,7 @@ refused. Someone has to draw the line, and for YAML::Tiny that someone
 is me.
 
 If you need something with more power move up to L<YAML> (4 megabytes of
-memory overhead) or L<YAML::Syck> (275k, but requires libsyck and a C
+memory overhead) or L<YAML::Syck> (275k, but requires F<libsyck> and a C
 compiler).
 
 To restate, L<YAML::Tiny> does B<not> preserve your comments, whitespace,
@@ -763,8 +773,10 @@ The purpose of the YAML Tiny specification is to describe a useful subset
 of the YAML specification that can be used for typical document-oriented
 use cases such as configuration files and simple data structure dumps.
 
+=for stopwords extensibility
+
 Many specification elements that add flexibility or extensibility are
-intentionally removed, as is support for complex datastructures, class
+intentionally removed, as is support for complex data structures, class
 and object-orientation.
 
 In general, the YAML Tiny language targets only those data structures
@@ -773,7 +785,9 @@ are supported.
 
 As a result, all possible YAML Tiny documents should be able to be
 transformed into an equivalent JSON document, although the reverse is
-not necesarily true (but will be true in simple cases).
+not necessarily true (but will be true in simple cases).
+
+=for stopwords PCRE
 
 As a result of these simplifications the YAML Tiny specification should
 be implementable in a (relatively) small amount of code in any language
@@ -800,6 +814,8 @@ The use of "null" type scalars is supported via the ~ character.
 
 The use of "bool" type scalars is not supported.
 
+=for stopwords serializer
+
 However, serializer implementations should take care to explicitly escape
 strings that match a "bool" keyword in the following set to prevent other
 implementations that do support "bool" accidentally reading a string as a
@@ -817,6 +833,8 @@ The use of directives is supported only for the %YAML directive.
 
 B<Processes>
 
+=for stopwords deserialization
+
 The YAML specification dictates three-phase serialization and three-phase
 deserialization.
 
@@ -827,6 +845,8 @@ Any compliant parser is only required to parse a single document at a
 time. The ability to support streaming documents is optional and most
 likely non-typical.
 
+=for stopwords acyclic
+
 Because anchors and aliases are not supported, the resulting representation
 graph is thus directed but (unlike the main YAML specification) B<acyclic>.
 
@@ -835,6 +855,8 @@ detecting a circular reference should error with an appropriate message.
 
 B<Presentation Stream>
 
+=for stopwords unicode
+
 YAML Tiny is notionally unicode, but support for unicode is required if the
 underlying language or system being used to implement a parser does not
 support Unicode. If unicode is encountered in this case an error should be
@@ -842,9 +864,13 @@ returned.
 
 B<Loading Failure Points>
 
+=for stopwords modality
+
+=for stopwords parsers
+
 YAML Tiny parsers and emitters are not expected to recover from adapt to
 errors. The specific error modality of any implementation is not dictated
-(return codes, exceptions, etc) but is expected to be consistant.
+(return codes, exceptions, etc) but is expected to be consistent.
 
 =head2 4. Syntax
 
@@ -921,8 +947,8 @@ To provide the ability to support empty sequences
 and mappings, support for the constructs [] (empty sequence) and {}
 (empty mapping) are required.
 
-For example, 
-  
+For example,
+
   %YAML 1.1
   # A document consisting of only an empty mapping
   --- {}
@@ -945,7 +971,7 @@ Indentation spaces work as per the YAML specification in all cases.
 Comments work as per the YAML specification in all simple cases.
 Support for indented multi-line comments is B<not> required.
 
-Seperation spaces work as per the YAML specification in all cases.
+Separation spaces work as per the YAML specification in all cases.
 
 B<YAML Tiny Character Stream>
 
@@ -953,6 +979,8 @@ The only directive supported by the YAML Tiny specification is the
 %YAML language/version identifier. Although detected, this directive
 will have no control over the parsing itself.
 
+=for stopwords recognise
+
 The parser must recognise both the YAML 1.0 and YAML 1.1+ formatting
 of this directive (as well as the commented form, although no explicit
 code should be needed to deal with this case, being a comment anyway)
@@ -978,7 +1006,7 @@ Support for the document boundary marker "---" is required.
 
 Support for the document boundary market "..." is B<not> required.
 
-If necesary, a document boundary should simply by indicated with a
+If necessary, a document boundary should simply by indicated with a
 "---" marker, with not preceding "..." marker.
 
 Support for empty streams (containing no documents) is required.
@@ -1037,6 +1065,8 @@ Support for quoted keys in mappings is B<not> required.
 
 Support for "?"-indicated explicit keys is B<not> required.
 
+=for stopwords endeth
+
 Here endeth the specification.
 
 =head2 Additional Perl-Specific Notes
@@ -1053,6 +1083,8 @@ specification are not required to retain the distinctiveness of 3 vs "3".
 
 =head1 METHODS
 
+=for Pod::Coverage HAVE_UTF8 refaddr
+
 =head2 new
 
 The constructor C<new> creates and returns an empty C<YAML::Tiny> object.
@@ -1065,7 +1097,7 @@ and returns a new C<YAML::Tiny> object containing the parsed content.
 Returns the object on success, or C<undef> on error.
 
 When C<read> fails, C<YAML::Tiny> sets an error message internally
-you can recover via C<YAML::Tiny-E<gt>errstr>. Although in B<some>
+you can recover via C<< YAML::Tiny->errstr >>. Although in B<some>
 cases a failed C<read> will also set the operating system error
 variable C<$!>, not all errors do and you should not rely on using
 the C<$!> variable.
@@ -1088,6 +1120,8 @@ Returns true on success or C<undef> on error.
 
 Generates the file content for the object and returns it as a string.
 
+=for stopwords errstr
+
 =head2 errstr
 
 When an error occurs, you can retrieve the error message either from the
@@ -1107,7 +1141,7 @@ to explicitly import the functions.
 Turn Perl data into YAML. This function works very much like
 Data::Dumper::Dumper().
 
-It takes a list of Perl data strucures and dumps them into a serialized
+It takes a list of Perl data structures and dumps them into a serialized
 form.
 
 It returns a string containing the YAML stream.
@@ -1159,8 +1193,21 @@ Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 SEE ALSO
 
-L<YAML>, L<YAML::Syck>, L<Config::Tiny>, L<CSS::Tiny>,
-L<http://use.perl.org/~Alias/journal/29427>, L<http://ali.as/>
+=over 4
+
+=item * L<YAML>
+
+=item * L<YAML::Syck>
+
+=item * L<Config::Tiny>
+
+=item * L<CSS::Tiny>
+
+=item * L<http://use.perl.org/use.perl.org/_Alias/journal/29427.html>
+
+=item * L<http://ali.as/>
+
+=back
 
 =head1 COPYRIGHT
 
